# Changelog

All notable changes to **Tail** will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.3] - 2026-03-11

### Fixed

- Fixed an issue where the RTVI message label module path changed in 0.0.105.

## [0.0.2] - 2025-10-24

### Changed

- Scripts `pipecat-tail` and `pctail` have been removed. Install `pipecat-cli`
  instead and use with `pipecat tail`.

## [0.0.1] - 2025-10-02

Initial public release.
